/*
 * @author G"unther Gst"ottner and Christian Ropposch, members of the ISAC-team, 
 * Copyright (c) 2007 by G"unther Gst"ottner and Christian Ropposch 
 * created Jun 13, 2007 5:53:44 PM
 * Institute for Softwaretechnology, Graz University of Technology, Austria.
 * 
 * Use is subject to PGPL license terms.
 */
package isac.gui;

import isac.browserdialog.IBrowserDialog;
import isac.interfaces.ICalcIterator;
import isac.interfaces.IToGUI;
import isac.interfaces.IToUser;
import isac.useractions.EUIContext;
import isac.useractions.EUIElement;
import isac.useractions.IUIAction;
import isac.useractions.IUserAction;
import isac.useractions.UIActionOnBrowserDialog;
import isac.useractions.UIActionOnWSDialog;
import isac.useractions.UserAction;
import isac.util.CalcChanged;
import isac.util.CalcEvent;
import isac.util.formulae.CalcFormula;
import isac.wsdialog.DialogProtocolException;
import isac.wsdialog.IWorksheetDialog;

import java.io.Serializable;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.util.Vector;

import org.apache.log4j.Logger;

/**
 * this shall partly become the isacweb.stubs.Tab
 */
public class MockTab extends UnicastRemoteObject implements IToGUI,
        Serializable, IToUser {

    private static final long serialVersionUID = 5527015901190435537L;

    private static final Logger logger = Logger.getLogger(MockTab.class
            .getName());

    private IBrowserDialog browserDialog;

    private IWorksheetDialog worksheetDialog;

    public MockTab() throws RemoteException {
        super();
    }

    public IBrowserDialog getBrowserDialog() {
        return browserDialog;
    }

    public IWorksheetDialog getWorksheetDialog() {
        return worksheetDialog;
    }

    public void doUIAction(IUIAction action) throws RemoteException {
        // catch action to get the browserdialog from the Session
        // (WindowApplication.java)
        System.out.println("action" + action.getAction());
        if (action.getAction() == EUIElement.UI_OPEN_BROWSER_FRAME) {
            if (action instanceof UIActionOnBrowserDialog) {
                UIActionOnBrowserDialog actionOnBrowserDialog = (UIActionOnBrowserDialog) action;
                if (browserDialog == null) {
                    browserDialog = actionOnBrowserDialog.getBrowserDialog();
                    try {
                        browserDialog.registerBrowserFrame(this);
                        browserDialog.notifyUserAction(new UserAction(
                                EUIElement.UI_BROWSER_GOT_FOCUS,
                                EUIContext.UI_CONTEXT_BROWSER));
                    } catch (DialogProtocolException e) {
                        e.printStackTrace();
                    }
                }
            }
        }

        // catch action to get the worksheetdialog from the Session
        // (WindowApplication.java)
        if (action.getAction() == EUIElement.UI_OPEN_WORKSHEET) {
            if (action instanceof UIActionOnWSDialog) {
                UIActionOnWSDialog actionOnWsSDialog = (UIActionOnWSDialog) action;
                if (worksheetDialog == null) {
                    worksheetDialog = actionOnWsSDialog.getWorksheetDialog();
                }
            }
        }
    }

    public void addUIElement(IUIAction action) throws RemoteException {
        // System.out.println("addUIElement(IUIAction action), "
        // + action.getAction());
    }

    /**
     * @deprecated in favour of void doUIAction(IUIAction action)
     */
    public boolean doUIAction(IUserAction action) throws RemoteException {
        // System.out.println("doUIAction(IUserAction action)");
        return false;
    }

    // catch calcChanged to get the result of the calculation
    public void calcResponse(CalcEvent event) throws RemoteException {
        ICalcIterator from = ((CalcChanged) event).getLastUnchangedFormula();
        ICalcIterator to = ((CalcChanged) event).getLastGeneratedFormula();

        Vector calculation = from.getFormulaeFromTo(to, 3, false);
        for (int i = 0; i < calculation.size(); i++) {
            CalcFormula formula = (CalcFormula) calculation.elementAt(i);

            System.out.println(createEmptyString(formula.getPosition()
                    .getLevel())
                    + formula);
        }
    }

    private String createEmptyString(int count) {
        String ret = "";
        if (count > 0) {
            for (int i = 0; i < count; i++) {
                ret += "     ";
            }
        }
        return ret;
    }

    public boolean isUIRunning() throws RemoteException {
        return false;
    }

    public boolean removeUIElement(IUIAction action) throws RemoteException {
        return false;
    }

}