/*
 * @author Christian Ropposch, member of the ISAC-team, 
 * Copyright (c) 2007 by Walther Neuper
 * created Jul 30, 2007 12:50:43 PM
 * Institute for Softwaretechnology, Graz University of Technology, Austria.
 * 
 * Use is subject to PGPL license terms.
 */
package isac.users;

import isac.useractions.EUIElement;

import java.net.URL;
import java.sql.Date;

/**
 * This is the record of data stored for one step by the <code>UserLogger</code>
 * 
 * @see isac.users.UserLogger
 * 
 * @author Christian Ropposch
 */
public class UserRecord {

    private String user_name_;

    private String session_;

    /**
     * The dialog the <code>UserAction</code> comes from.
     */
    private String dialog_;

    /**
     * A string describing the <code>UserAction</code>; usually got from
     * <code>EUIElement</code> isac.useractions.IUserAction.getActionID()
     */
    private String step_;

    /**
     * WN070913 TOOODO set where ???
     */
    // private Date time_;
    /**
     * The ID of the <code>Worksheet</code> the <code>UserAction</code>
     * comes from, XOR the ID of the <code>Worksheet</code> containing the
     * context of the KnowledgeBrowser the <code>UserAction</code> comes from.
     * The ID == null iff there is no context for the KnowledgeBrowser OR no
     * <code>Worksheet</code>.
     */
    private String worksheet_;

    /**
     * The <code>Position</code> of the <code>CalcFormula</code> last agreed
     * on with the user, i.e. the <code>Position</code> in
     * <code>CalcChanged#getLastUnchangedFormula()</code>.
     * 
     * @see <code>formula_from_</code>
     */
    private String position_;

    /**
     * The <code>CalcFormula</code> last agreed on with the user, i.e. the
     * <code>CalcChanged#getLastUnchangedFormula()</code>.
     * 
     * @see <code>position_</code>
     */
    private String formula_from_;

    /**
     * The <code>CalcFormula</code> last agreed on with the user, i.e. ...
     * 
     * @see <code>CalcChanged#getLastGeneratedFormula()</code>
     */
    private String formula_to_;

    /**
     * The respective argument of the <code>UserAction</code> in
     * <code>step_</code>.
     */
    private String argument_;

    /**
     * The substitution, a specific and additional argument of certain steps
     * concerning rewriting (tactic "Rewrite*")
     * 
     * WN070913 may be used as and renamed to argument2_
     */
    private String subst_;

    /**
     * The success of the <code>step_</code>; TODO.WN070913 relate to ...
     * 
     * @see <code>isac.users.SuccessInfo</code>
     */
    private Float success_;

    /**
     * <code></code>
     */
    void setUser_name(String user_name_) {
        this.user_name_ = user_name_;
    }

    String getUser_name() {
        return user_name_;
    }

    void setSession(String session_) {
        this.session_ = session_;
    }

    String getSession() {
        return session_;
    }

    void setDialog(String dialog_) {
        this.dialog_ = dialog_;
    }

    String getDialog() {
        return dialog_;
    }

    void setStep(String step_) {
        this.step_ = step_;
    }

    String getStep() {
        return step_;
    }

    void setWorksheet(String worksheet_) {
        this.worksheet_ = worksheet_;
    }

    String getWorksheet() {
        return worksheet_;
    }

    void setPosition(String position_) {
        this.position_ = position_;
    }

    String getPosition() {
        return position_;
    }

    void setFormula_from(String formula_from_) {
        this.formula_from_ = formula_from_;
    }

    String getFormula_from() {
        return formula_from_;
    }

    void setFormula_to(String formula_to_) {
        this.formula_to_ = formula_to_;
    }

    String getFormula_to() {
        return formula_to_;
    }

    void setArgument(String argument_) {
        this.argument_ = argument_;
    }

    String getArgument() {
        return argument_;
    }

    void setSubst(String subst_) {
        this.subst_ = subst_;
    }

    String getSubst() {
        return subst_;
    }

    void setSucces(Float success_) {
        this.success_ = success_;
    }

    Float getSucces() {
        return success_;
    }

    /**
     * Set the data known already from a <code>UserAction</code>
     * 
     * @see <isac.users.UserRecord#setResult(param-classes)>
     */
    public void setAction(String user_name, String session, String dialog,
            EUIElement step, String argument, String subst) {
        user_name_ = user_name;
        session_ = session;
        dialog_ = dialog;
        step_ = step.name();
        argument_ = argument;
        subst_ = subst;
    }

    /**
     * Complete the data known already from a <code>UserAction</code> by the
     * respective result obtained from the <code>MathEngine</code>.
     * 
     * @see <isac.users.UserRecord#setAction(param-classes)>
     */
    public void setResult(String worksheet, String position,
            String formula_from, String formula_to, Float success) {
        worksheet_ = worksheet;
        position_ = position;
        formula_from_ = formula_from;
        formula_to_ = formula_to;
        success_ = success;
    }

    public void reset() {
        user_name_ = null;
        session_ = null;
        dialog_ = null;
        step_ = null;
        // time_ = null;
        worksheet_ = null;
        position_ = null;
        formula_from_ = null;
        formula_to_ = null;
        argument_ = null;
        subst_ = null;
        success_ = null;
    }
}
